Stan Math Library: stan/math/prim/mat/fun/inverse.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
inverse.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/mat/err/check_square.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T , int R, int C>
Eigen::Matrix< T, R, C > | stan::math::inverse (const Eigen::Matrix< T, R, C > &m)
| Returns the inverse of the specified matrix. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.